pub enum SourceRealm {
AnyRealm(bool),
RealmId(u32),
}Expand description
Source realm selector. “self” in config is resolved to realm_id by actor before registration; “*” in config maps to any_realm = true.
Variants
Implementations
Sourceimpl SourceRealm
impl SourceRealm
Sourcepub fn merge(
field: &mut Option<SourceRealm>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<SourceRealm>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.