#[repr(i32)]pub enum RegisterAuthMode {
Unspecified = 0,
Package = 1,
Linked = 2,
}Expand description
========================================================================= Register
Variants
Unspecified = 0
Package = 1
Package-backed registration authenticated by MFR package lookup, manifest signature verification, or package renewal credentials.
Linked = 2
Source-linked workload registration authenticated by realm authorization.
Implementations
Sourceimpl RegisterAuthMode
impl RegisterAuthMode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.