pub struct IceRestartRequest {
pub reason: Option<String>,
}Expand description
Answerer notifies Offerer that its network has recovered, so the Offerer should immediately retry ICE restart instead of waiting for its backoff timer to expire.
Fields
reason: Option<String>e.g. “network_recovered”, “network_type_changed”
Implementations